@@ -3,20 +3,16 @@ package My::Module::Build;
 use strict;
 use warnings;
 
-use Module::Build;
-our @ISA = qw{ Module::Build };
+use base qw{ Module::Build };
 
 use Carp;
 
 
 sub ACTION_authortest {
-##  my ( $self, @args ) = @_;
-    my ( $self ) = @_;			# Arguments unused
-
-    local $ENV{AUTHOR_TESTING} = 1;
+    my ( $self, @args ) = @_;
 
     $self->depends_on( 'build' );
-    $self->test_files( qw{ t xt/author } );
+    $self->test_files( qw{ t xt } );
     $self->depends_on( 'test' );
 
     return;
@@ -79,7 +75,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009, 2012-2019 Thomas R. Wyant, III
+Copyright (C) 2009, Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
