@@ -1,14 +1,13 @@
 package Astro::UTDF;
 
-use 5.006002;
-
 use strict;
 use warnings;
 
 use Carp;
 use IO::File ();
+use Params::Util 0.25 qw{ _INSTANCE };
 use POSIX qw{ floor };
-use Scalar::Util qw{ blessed openhandle };
+use Scalar::Util qw{ openhandle };
 use Time::Local;
 
 use constant FULL_CIRCLE => 4294967296;	# 2 ** 32;
@@ -16,10 +15,7 @@ use constant PI => atan2( 0, -1 );
 use constant TWO_PI => 2 * PI;
 use constant SPEED_OF_LIGHT => 299792.458;	# Km/sec, per U.S. NIST
 
-use constant ARRAY_REF	=> ref [];
-use constant CODE_REF	=> ref sub {};
-
-our $VERSION = '0.011_01';
+our $VERSION = '0.001';
 
 sub new {
     my $class = shift;
@@ -186,9 +182,9 @@ sub data_interval {
 	    or return $self->$method( @args );
 	my $type = ref $dcdr
 	    or return sprintf $dcdr, $self->$method( @args );
-	ARRAY_REF eq $type
+	'ARRAY' eq $type
 	    and return $dcdr->[ $self->$method( @args ) ];
-	CODE_REF eq $type
+	'CODE' eq $type
 	    and return $dcdr->( $self, $method, @args );
 	confess "Programming error -- decoder for $method is $type";
     }
@@ -353,7 +349,7 @@ sub prior_record {
     my ( $self, @args ) = @_;
     if ( @args ) {
 	my $prior = shift @args;
-	defined $prior and not __PACKAGE__->_instance( $prior )
+	defined $prior and not _INSTANCE( $prior, __PACKAGE__ )
 	    and croak 'Prior record must be undef or an ', __PACKAGE__,
 		' object';
 	$self->{prior_record} = $prior;
@@ -464,7 +460,7 @@ sub receive_antenna_geometry_code {
     my %my_arg = map { $_ => 1 } qw{ file };
 
     sub slurp {
-	my ( undef, @in_args ) = @_;		# Invocant unused
+	my ( $class, @in_args ) = @_;
 
 	@in_args % 2 and unshift @in_args, 'file';
 	my ( %arg, @attrib );
@@ -670,23 +666,6 @@ sub _bash_nybble {
     }
 }
 
-# $class->_instance( $obj )
-# returns the class name of the invocant if the argument is an instance
-# of the invocant's class, or one of its subclasses. Otherwise simply
-# returns. Can be called as a static method.
-sub _instance {
-    my ( $class, $obj ) = @_;
-    ref $class
-	and $class = ref $class;
-    ref $obj
-	or return;
-    blessed( $obj )
-	or return;
-    $obj->isa( $class )
-	or return;
-    return $class;
-}
-
 1;
 
 __END__
@@ -985,7 +964,7 @@ frequency band to a number from 0 to 15; this number comes from the low
 4 bits of the argument.
 
 The frequency band is found in the high nybble of the
-L</frequency_band_and_transmission_type>, and the encoding is documented
+L</frequency_code_and_transmission_type>, and the encoding is documented
 there.
 
 =head2 frequency_band_and_transmission_type
@@ -1616,7 +1595,7 @@ transmission type to a number from 0 to 15; this number comes from the low
 4 bits of the argument.
 
 The transmission type is found in the low nybble of the
-L</frequency_band_and_transmission_type>, and the encoding is documented
+L</frequency_code_and_transmission_type>, and the encoding is documented
 there.
 
 =head2 transmit_antenna_padid
@@ -1761,9 +1740,7 @@ This information comes from byte 6 of the record.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-UTDF>,
-L<https://github.com/trwyant/perl-Astro-UTDF/issues>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 ACKNOWLEDGMENT
 
@@ -1776,7 +1753,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2021 Thomas R. Wyant, III
+Copyright (C) 2010, Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
